@@ -37,6 +37,7 @@ SharedMem *sm;
 HANDLE hSharedMutex = NULL;
 HMODULE hSelf = NULL;
 
+int iShouldPatch = 0;
 bool bVideoHooked = false;
 unsigned int uiAudioCount = 0;
 
@@ -151,30 +152,51 @@ void __cdecl ods(const char *format, ...) {
 	}
 }
 
-static LRESULT CALLBACK CallWndProc(int nCode, WPARAM wParam, LPARAM lParam) {
-	char procname[1024];
-	GetModuleFileName(NULL, procname, 1024);
+static const char *blacklist[] = {
+	"mumble.exe",
+	"iexplore.exe",
+	"ieuser.exe",
+	"vlc.exe",
+	"dbgview.exe",
+	"opera.exe",
+	NULL
+};
 
-	if (strstr(procname, "mumble.exe") == NULL) {
-		CWPSTRUCT *s = reinterpret_cast<CWPSTRUCT *>(lParam);
-		if (s) {
-			switch (s->message) {
-				case WM_CREATE:
-				case WM_DESTROY:
-				case WM_SETFOCUS:
-				case WM_GETMINMAXINFO:	// For things that link directly
-				case WM_GETICON:		// Worked for BF2
-				case WM_NCCREATE:		// Lots of games
-					checkD3D9Hook();
-					checkOpenGLHook();
-					// checkOpenALHook();
-					// checkDSHook(s->hwnd);
-					break;
-				default:
-					break;
+static LRESULT CALLBACK CallWndProc(int nCode, WPARAM wParam, LPARAM lParam) {
+	char procname[1024+64];
+	HANDLE h;
+
+	if (iShouldPatch == 0) {
+		iShouldPatch = 1;
+
+		GetModuleFileName(NULL, procname, 1024);
+
+		char *p = strrchr(procname, '\\');
+
+		if (p) {
+			int i =0;
+			while (blacklist[i]) {
+				if (_stricmp(p+1,blacklist[i])==0) {
+					ods("Process %s is blacklisted", procname);
+					iShouldPatch = -1;
+				}
+				i++;
+			}
+			strcpy_s(p+1, 64, "nooverlay");
+
+			h = CreateFile(procname, GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
+			if (h != INVALID_HANDLE_VALUE) {
+				CloseHandle(h);
+				ods("Overlay disable %s found", procname);
+				iShouldPatch = -1;
 			}
 		}
 	}
+
+	if (iShouldPatch > 0) {
+		checkD3D9Hook();
+		checkOpenGLHook();
+	}
 	return CallNextHookEx(hhookWnd, nCode, wParam, lParam);
 }
 
@@ -202,7 +224,7 @@ extern "C" __declspec(dllexport) void __cdecl InstallHooks() {
 			if (hSelf == NULL) {
 				ods("Lib: Failed to find myself");
 			} else {
-				hhookWnd = SetWindowsHookEx(WH_CALLWNDPROC,CallWndProc,hSelf,0);
+				hhookWnd = SetWindowsHookEx(WH_CBT, CallWndProc, hSelf, 0);
 				if (hhookWnd == NULL)
 					ods("Lib: Failed to insert WNDProc hook");
 			}
@@ -221,12 +243,8 @@ extern "C" BOOL WINAPI DllMain(HINSTANCE, DWORD fdwReason, LPVOID) {
 	char procname[1024];
 	GetModuleFileName(NULL, procname, 1024);
 
-//	if ((strstr(procname, "mumble.exe") == NULL) && (strstr(procname, "Text3D.exe") == NULL) && (strstr(procname, "Lesson5.exe") == NULL))
-//		return TRUE;
-
 	switch (fdwReason) {
 		case DLL_PROCESS_ATTACH: {
-				ods("Lib: ProcAttach: %s", procname);
 				hSharedMutex = CreateMutex(NULL, false, "MumbleSharedMutex");
 				hHookMutex = CreateMutex(NULL, false, "MumbleHookMutex");
 				if ((hSharedMutex == NULL) || (hHookMutex == NULL)) {
@@ -270,6 +288,7 @@ extern "C" BOOL WINAPI DllMain(HINSTANCE, DWORD fdwReason, LPVOID) {
 					sm->fFontSize = 72;
 				}
 				ReleaseMutex(hSharedMutex);
+				ods("Lib: ProcAttach: %s", procname);
 			}
 			break;
 		case DLL_PROCESS_DETACH: {
