@@ -60,8 +60,8 @@
 #endif
 
 #include <math.h>
-#include "speex/speex_preprocess.h"
-#include "speex/speex_echo.h"
+#include "../include/speex/speex_preprocess.h"
+#include "../include/speex/speex_echo.h"
 #include "arch.h"
 #include "fftwrap.h"
 #include "filterbank.h"
@@ -704,7 +704,7 @@ static void update_noise_prob(SpeexPreprocessState *st)
    }
    for (i=0;i<N;i++)
    {
-      if (MULT16_32_Q15(QCONST16(.4f,15),st->S[i]) > ADD32(st->Smin[i],EXTEND32(20)))
+      if (MULT16_32_Q15(QCONST16(.4f,15),st->S[i]) > st->Smin[i])
          st->update_prob[i] = 1;
       else
          st->update_prob[i] = 0;
@@ -1169,7 +1169,7 @@ EXPORT int speex_preprocess_ctl(SpeexPreprocessState *state, int request, void *
       st->echo_state = (SpeexEchoState*)ptr;
       break;
    case SPEEX_PREPROCESS_GET_ECHO_STATE:
-      ptr = (void*)st->echo_state;
+      (*(SpeexEchoState**)ptr) = (SpeexEchoState*)st->echo_state;
       break;
 #ifndef FIXED_POINT
    case SPEEX_PREPROCESS_GET_AGC_LOUDNESS:
@@ -1194,7 +1194,7 @@ EXPORT int speex_preprocess_ctl(SpeexPreprocessState *state, int request, void *
    case SPEEX_PREPROCESS_GET_PROB:
       (*(spx_int32_t*)ptr) = MULT16_16_Q15(st->speech_prob, 100);
       break;
-#ifndef DISABLE_FLOAT_API
+#ifndef FIXED_POINT
    case SPEEX_PREPROCESS_SET_AGC_TARGET:
       st->agc_level = (*(spx_int32_t*)ptr);
       if (st->agc_level<1)
@@ -1205,7 +1205,7 @@ EXPORT int speex_preprocess_ctl(SpeexPreprocessState *state, int request, void *
    case SPEEX_PREPROCESS_GET_AGC_TARGET:
       (*(spx_int32_t*)ptr) = st->agc_level;
       break;
-#endif /* #ifndef DISABLE_FLOAT_API */
+#endif
    default:
       speex_warning_int("Unknown speex_preprocess_ctl request: ", request);
       return -1;
