@@ -50,6 +50,12 @@ Channel::Channel(int id, QString name, QObject *p) : QObject(p) {
 }
 
 Channel::~Channel() {
+	if (cParent)
+		cParent->removeChannel(this);
+
+	foreach(Channel *c, qlChannels)
+	delete c;
+
 	foreach(ChanACL *acl, qlACL)
 	delete acl;
 	foreach(Group *g, qhGroups)
@@ -58,10 +64,14 @@ Channel::~Channel() {
 	unlink(l);
 
 	Q_ASSERT(qlChannels.count() == 0);
-	Q_ASSERT(qlPlayers.count() == 0);
 	Q_ASSERT(children().count() == 0);
 }
 
+bool Channel::validateName(const QString &qsName) {
+	QRegExp re(QLatin1String("[ \\-=\\w\\#\\[\\]\\{\\}\\(\\)\\@\\|]+"));
+	return re.exactMatch(qsName);
+}
+
 Channel *Channel::get(int id) {
 	QReadLocker lock(&c_qrwlChannels);
 	return c_qhChannels.value(id);
