@@ -82,12 +82,15 @@ AudioOutputPtr AudioOutputRegistrar::newFromChoice(QString choice) {
 AudioOutputPlayer::AudioOutputPlayer(const QString name) : qsName(name) {
 	iBufferSize = 0;
 	pfBuffer = NULL;
+	pfVolume = NULL;
 	fPos[0]=fPos[1]=fPos[2]=0.0;
 }
 
 AudioOutputPlayer::~AudioOutputPlayer() {
 	if (pfBuffer)
 		delete [] pfBuffer;
+	if (pfVolume)
+		delete [] pfVolume;
 }
 
 void AudioOutputPlayer::resizeBuffer(unsigned int newsize) {
@@ -118,7 +121,7 @@ AudioOutputSpeech::AudioOutputSpeech(ClientPlayer *player, unsigned int freq) :
 	else
 		srs = NULL;
 
-	iOutputSize = lroundf(ceilf((iFrameSize * freq) / (SAMPLE_RATE * 1.0f)));
+	iOutputSize = lroundf(ceilf(static_cast<float>(iFrameSize * freq) / static_cast<float>(SAMPLE_RATE)));
 
 	iBufferOffset = iBufferFilled = iLastConsume = 0;
 	bLastAlive = true;
@@ -155,7 +158,7 @@ int AudioOutputSpeech::speexCallback(SpeexBits *bits, void *, void *data) {
 	unsigned char *ptr = reinterpret_cast<unsigned char *>(qba.data());
 
 	for (int i=0;i<len;i++)
-		ptr[i]=speex_bits_unpack_unsigned(bits, 8);
+		ptr[i]=static_cast<unsigned char>(speex_bits_unpack_unsigned(bits, 8));
 	QDataStream ds(qba);
 	ds >> aos->fPos[0];
 	ds >> aos->fPos[1];
@@ -316,12 +319,9 @@ float AudioOutput::calcGain(float dotproduct, float distance) {
 	return att;
 }
 
-void AudioOutput::newPlayer(AudioOutputPlayer *) {
-}
-
 void AudioOutput::wipe() {
-	foreach(const ClientPlayer *p, qmOutputs.keys())
-	removeBuffer(p);
+	foreach(AudioOutputPlayer *aop, qmOutputs)
+	removeBuffer(aop);
 }
 
 const float *AudioOutput::getSpeakerPos(unsigned int &speakers) {
@@ -338,13 +338,12 @@ AudioSine *AudioOutput::playSine(float hz, float i, unsigned int frames, float v
 	qrwlOutputs.lockForWrite();
 	AudioSine *as = new AudioSine(hz,i,frames, volume, iMixerFreq);
 	qmOutputs.insert(NULL, as);
-	newPlayer(as);
 	qrwlOutputs.unlock();
 	return as;
 }
 
 void AudioOutput::addFrameToBuffer(ClientPlayer *player, const QByteArray &qbaPacket, unsigned int iSeq) {
-	if (iChannels == 0) 
+	if (iChannels == 0)
 		return;
 	qrwlOutputs.lockForRead();
 	AudioOutputSpeech *aop = dynamic_cast<AudioOutputSpeech *>(qmOutputs.value(player));
@@ -356,7 +355,6 @@ void AudioOutput::addFrameToBuffer(ClientPlayer *player, const QByteArray &qbaPa
 		qrwlOutputs.lockForWrite();
 		aop = new AudioOutputSpeech(player, iMixerFreq);
 		qmOutputs.replace(player,aop);
-		newPlayer(aop);
 	}
 
 	aop->addFrameToBuffer(qbaPacket, iSeq);
@@ -370,14 +368,13 @@ void AudioOutput::removeBuffer(const ClientPlayer *player) {
 
 void AudioOutput::removeBuffer(AudioOutputPlayer *aop) {
 	QWriteLocker locker(&qrwlOutputs);
-	QMultiHash<const ClientPlayer *, AudioOutputPlayer *>::iterator i=qmOutputs.begin();
-	while (i != qmOutputs.end()) {
+	QMultiHash<const ClientPlayer *, AudioOutputPlayer *>::iterator i;
+	for (i=qmOutputs.begin(); i != qmOutputs.end(); ++i) {
 		if (i.value() == aop) {
 			qmOutputs.erase(i);
 			delete aop;
 			break;
 		}
-		++i;
 	}
 }
 
@@ -532,7 +529,7 @@ bool AudioOutput::mix(void *outbuff, unsigned int nsamp) {
 
 		memset(output, 0, sizeof(float) * nsamp * iChannels);
 
-		for (int i=0;i<iChannels;++i)
+		for (unsigned int i=0;i<iChannels;++i)
 			svol[i] = mul * fSpeakerVolume[i];
 
 		if (g.s.bPositionalAudio && (iChannels > 1) && g.p->fetch()) {
@@ -599,15 +596,23 @@ bool AudioOutput::mix(void *outbuff, unsigned int nsamp) {
 								qWarning("Voice pos: %f %f %f", aop->fPos[0], aop->fPos[1], aop->fPos[2]);
 								qWarning("Voice dir: %f %f %f", dir[0], dir[1], dir[2]);
 				*/
+				if (! aop->pfVolume) {
+					aop->pfVolume = new float[nchan];
+					for (unsigned int s=0;s<nchan;++s)
+						aop->pfVolume[s] = -1.0;
+				}
 				for (unsigned int s=0;s<nchan;++s) {
 					const float dot = bSpeakerPositional[s] ? dir[0] * speaker[s*3+0] + dir[1] * speaker[s*3+1] + dir[2] * speaker[s*3+2] : 1.0f;
 					const float str = svol[s] * calcGain(dot, len);
 					float * RESTRICT o = output + s;
+					const float old = (aop->pfVolume[s] >= 0.0) ? aop->pfVolume[s] : str;
+					const float inc = (str - old) / static_cast<float>(nsamp);
+					aop->pfVolume[s] = str;
 					/*
 										qWarning("%d: Pos %f %f %f : Dot %f Len %f Str %f", s, speaker[s*3+0], speaker[s*3+1], speaker[s*3+2], dot, len, str);
 					*/
 					for (unsigned int i=0;i<nsamp;++i)
-						o[i*nchan] += pfBuffer[i] * str;
+						o[i*nchan] += pfBuffer[i] * (old + inc*static_cast<float>(i));
 				}
 			} else {
 				for (unsigned int s=0;s<nchan;++s) {
@@ -641,10 +646,10 @@ bool AudioOutput::mix(void *outbuff, unsigned int nsamp) {
 }
 
 AudioSine::AudioSine(float hz, float i, unsigned int frm, float vol, unsigned int freq) : AudioOutputPlayer(QLatin1String("Sine")) {
-	float hfreq = freq / 2.0f;
+	float hfreq = static_cast<float>(freq) / 2.0f;
 	v = 0.0;
-	inc = M_PI * hz / hfreq;
-	dinc = M_PI * i / (hfreq * hfreq);
+	inc = static_cast<float>(M_PI * hz / hfreq);
+	dinc = static_cast<float>(M_PI * i / (hfreq * hfreq));
 	volume = vol * 32768.f;
 	frames = frm;
 	cntr = 0;
@@ -658,11 +663,10 @@ AudioSine::~AudioSine() {
 }
 
 bool AudioSine::needSamples(unsigned int snum) {
+	resizeBuffer(snum);
 	if (frames > 0) {
 		frames--;
 
-		resizeBuffer(snum);
-
 		if (inc == 0.0) {
 			if (++cntr == 50) {
 				bSearch = true;
@@ -679,8 +683,9 @@ bool AudioSine::needSamples(unsigned int snum) {
 			}
 
 			// FIXME: Not * snum, * something else
+			const float m = static_cast<float>(M_PI * static_cast<float>(tbin) / static_cast<float>(snum));
 			for (unsigned int i=0;i<snum;i++)
-				pfBuffer[i] = volume * sinf(M_PI * i * (tbin * 1.0f) / (1.0f * snum));
+				pfBuffer[i] = volume * sinf(m * static_cast<float>(i));
 
 			return true;
 		}
