@@ -94,6 +94,7 @@ class AudioOutputPlayer : public QObject {
 		~AudioOutputPlayer();
 		const QString qsName;
 		float *pfBuffer;
+		float *pfVolume;
 		float fPos[3];
 		virtual bool needSamples(unsigned int snum) = 0;
 };
@@ -164,7 +165,6 @@ class AudioOutput : public QThread {
 		QReadWriteLock qrwlOutputs;
 		QMultiHash<const ClientPlayer *, AudioOutputPlayer *> qmOutputs;
 
-		virtual void newPlayer(AudioOutputPlayer *);
 		virtual void removeBuffer(AudioOutputPlayer *);
 		void initializeMixer(const unsigned int *chanmasks, bool forceheadphone = false);
 		bool mix(void *output, unsigned int nsamp);
@@ -175,7 +175,7 @@ class AudioOutput : public QThread {
 		~AudioOutput();
 		void addFrameToBuffer(ClientPlayer *, const QByteArray &, unsigned int iSeq);
 		void removeBuffer(const ClientPlayer *);
-		AudioSine *playSine(float hz, float i = 0.0, unsigned int frames = 0xffffff, float volume = 0.3);
+		AudioSine *playSine(float hz, float i = 0.0, unsigned int frames = 0xffffff, float volume = 0.3f);
 		void run() = 0;
 		const float *getSpeakerPos(unsigned int &nspeakers);
 		static float calcGain(float dotproduct, float distance);
