@@ -85,8 +85,8 @@ bool AudioWizard::eventFilter(QObject *obj, QEvent *evt) {
 		if (qme) {
 			if (qme->buttons() & Qt::LeftButton) {
 				QPointF qpf = qgvView->mapToScene(qme->pos());
-				fX = qpf.x();
-				fY = qpf.y();
+				fX = static_cast<float>(qpf.x());
+				fY = static_cast<float>(qpf.y());
 			}
 		}
 	}
@@ -94,54 +94,51 @@ bool AudioWizard::eventFilter(QObject *obj, QEvent *evt) {
 }
 
 QWizardPage *AudioWizard::introPage() {
-	QWizardPage *qwpage = new QWizardPage;
+	QWizardPage *qwpage = new QWizardPage(this);
 	qwpage->setTitle(tr("Introduction"));
 	qwpage->setSubTitle(tr("Welcome to the Mumble Audio Wizard"));
-	QVBoxLayout *v=new QVBoxLayout;
+	QVBoxLayout *v=new QVBoxLayout(qwpage);
 	QLabel *label=new QLabel(tr("This is the audio tuning wizard for Mumble. This will help you correctly set the input levels of your sound card, and also set the correct "
-	                            "parameters for sound processing in Mumble."));
+	                            "parameters for sound processing in Mumble."), qwpage);
 	label->setWordWrap(true);
 	v->addWidget(label);
 
 	label=new QLabel(tr("Please be aware that as long as this wizard is active, audio will be looped locally to allow you to listen to it, and no audio will be sent to the "
-	                    "server."));
+	                    "server."), qwpage);
 	label->setWordWrap(true);
 	v->addWidget(label);
 
-	qwpage->setLayout(v);
 	return qwpage;
 }
 
 QWizardPage *AudioWizard::donePage() {
-	QWizardPage *qwpage = new QWizardPage;
+	QWizardPage *qwpage = new QWizardPage(this);
 	qwpage->setTitle(tr("Finished"));
 	qwpage->setSubTitle(tr("Enjoy using Mumble"));
-	QVBoxLayout *v=new QVBoxLayout;
-	QLabel *label=new QLabel(tr("Congratulations. You should now be ready to enjoy a richer sound experience with Mumble."));
+	QVBoxLayout *v=new QVBoxLayout(qwpage);
+	QLabel *label=new QLabel(tr("Congratulations. You should now be ready to enjoy a richer sound experience with Mumble."), qwpage);
 	label->setWordWrap(true);
 	v->addWidget(label);
 
-	qwpage->setLayout(v);
 	return qwpage;
 }
 
 QWizardPage *AudioWizard::devicePage() {
-	QWizardPage *qwpage = new QWizardPage;
+	QWizardPage *qwpage = new QWizardPage(this);
 	QLabel *l;
 	QGridLayout *grid;
 
 	qwpage->setTitle(tr("Device selection"));
 	qwpage->setSubTitle(tr("Selecting the input and output device to use with Mumble."));
 
+	QGroupBox *qgbInput = new QGroupBox(tr("Input device"), qwpage);
+	grid = new QGridLayout(qgbInput);
 
-	QGroupBox *qgbInput = new QGroupBox(tr("Input device"));
-	grid = new QGridLayout();
-
-	l = new QLabel(tr("This is the device your microphone is connected to."));
+	l = new QLabel(tr("This is the device your microphone is connected to."), qgbInput);
 	l->setWordWrap(true);
 	grid->addWidget(l, 0, 0, 1, 2);
 
-	qcbInput = new QComboBox();
+	qcbInput = new QComboBox(qgbInput);
 	if (AudioInputRegistrar::qmNew) {
 		foreach(AudioInputRegistrar *air, *AudioInputRegistrar::qmNew) {
 			qcbInput->addItem(air->name);
@@ -151,7 +148,7 @@ QWizardPage *AudioWizard::devicePage() {
 		}
 	}
 
-	l = new QLabel(tr("System"));
+	l = new QLabel(tr("System"), qgbInput);
 	l->setBuddy(qcbInput);
 
 	qcbInput->setToolTip(tr("Input method for audio"));
@@ -166,8 +163,8 @@ QWizardPage *AudioWizard::devicePage() {
 	grid->addWidget(qcbInput, 1, 1);
 
 
-	qcbInputDevice = new QComboBox();
-	l = new QLabel(tr("Device"));
+	qcbInputDevice = new QComboBox(qgbInput);
+	l = new QLabel(tr("Device"), qgbInput);
 	l->setBuddy(qcbInputDevice);
 
 	qcbInputDevice->setToolTip(tr("Input device to use"));
@@ -177,25 +174,21 @@ QWizardPage *AudioWizard::devicePage() {
 	grid->addWidget(l, 2, 0);
 	grid->addWidget(qcbInputDevice, 2, 1);
 
-	qcbEcho = new QCheckBox(tr("Use echo cancellation"));
+	qcbEcho = new QCheckBox(tr("Use echo cancellation"), qgbInput);
 	qcbEcho->setToolTip(tr("Cancel echo from headset or speakers."));
 	qcbEcho->setWhatsThis(tr("This enables echo cancellation of outgoing audio, which helps both on speakers and on headsets."));
 	qcbEcho->setObjectName(QLatin1String("Echo"));
 	qcbEcho->setChecked(g.s.bEcho);
 	grid->addWidget(qcbEcho, 3, 1);
 
-	qgbInput->setLayout(grid);
+	QGroupBox *qgbOutput = new QGroupBox(tr("Output device"), qwpage);
+	grid = new QGridLayout(qgbOutput);
 
-
-
-	QGroupBox *qgbOutput = new QGroupBox(tr("Output device"));
-	grid = new QGridLayout();
-
-	l = new QLabel(tr("This is the device your speakers or headphones are connected to."));
+	l = new QLabel(tr("This is the device your speakers or headphones are connected to."), qgbOutput);
 	l->setWordWrap(true);
 	grid->addWidget(l, 0, 0, 1, 2);
 
-	qcbOutput = new QComboBox();
+	qcbOutput = new QComboBox(qgbOutput);
 	if (AudioOutputRegistrar::qmNew) {
 		foreach(AudioOutputRegistrar *aor, *AudioOutputRegistrar::qmNew) {
 			qcbOutput->addItem(aor->name);
@@ -205,7 +198,7 @@ QWizardPage *AudioWizard::devicePage() {
 		}
 	}
 
-	l = new QLabel(tr("System"));
+	l = new QLabel(tr("System"), qgbOutput);
 	l->setBuddy(qcbOutput);
 
 	qcbOutput->setToolTip(tr("Output method for audio"));
@@ -220,8 +213,8 @@ QWizardPage *AudioWizard::devicePage() {
 	grid->addWidget(qcbOutput, 1, 1);
 
 
-	qcbOutputDevice = new QComboBox();
-	l = new QLabel(tr("Device"));
+	qcbOutputDevice = new QComboBox(qgbOutput);
+	l = new QLabel(tr("Device"), qgbOutput);
 	l->setBuddy(qcbOutputDevice);
 
 	qcbOutputDevice->setToolTip(tr("Output device to use"));
@@ -231,21 +224,17 @@ QWizardPage *AudioWizard::devicePage() {
 	grid->addWidget(l, 2, 0);
 	grid->addWidget(qcbOutputDevice, 2, 1);
 
-	qcbPositional = new QCheckBox(tr("Enable positional audio"));
+	qcbPositional = new QCheckBox(tr("Enable positional audio"), qgbOutput);
 	qcbPositional->setToolTip(tr("Allows positioning of sound."));
 	qcbPositional->setWhatsThis(tr("This allows Mumble to use positional audio to place voices."));
 	qcbPositional->setObjectName(QLatin1String("Positional"));
 	qcbPositional->setChecked(g.s.bPositionalAudio);
 	grid->addWidget(qcbPositional, 3, 1);
 
-	qgbOutput->setLayout(grid);
-
-	QVBoxLayout *v=new QVBoxLayout;
+	QVBoxLayout *v=new QVBoxLayout(qwpage);
 	v->addWidget(qgbInput);
 	v->addWidget(qgbOutput);
 
-	qwpage->setLayout(v);
-
 	on_Input_activated(qcbInput->currentIndex());
 	on_Output_activated(qcbOutput->currentIndex());
 
@@ -253,32 +242,28 @@ QWizardPage *AudioWizard::devicePage() {
 }
 
 QWizardPage *AudioWizard::positionalPage() {
-	QWizardPage *qwpage = new QWizardPage;
+	QWizardPage *qwpage = new QWizardPage(this);
 	qwpage->setTitle(tr("Positional Audio"));
 	qwpage->setSubTitle(tr("Adjusting attenuation of positional audio."));
 
-	QVBoxLayout *v = new QVBoxLayout();
+	QVBoxLayout *v = new QVBoxLayout(qwpage);
 	QLabel *l;
 
 	l = new QLabel(tr("Mumble supports positional audio for some games, and will position the voice of other players relative to their position in game. Depending on their position, the "
 	                  "volume of the voice will be changed between the speakers to simulate the direction and distance the other player is at. Such positioning depends on your speaker "
-	                  "configuration being correct in your operating system, so a test is done here."));
+	                  "configuration being correct in your operating system, so a test is done here."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
-	l = new QLabel(tr("The graph below shows the position of <font color=\"red\">you</font>, the <font color=\"yellow\">speakers</font> and a <font color=\"green\">moving sound source</font> as if seen from above. You should hear the audio move between the channels."));
+	l = new QLabel(tr("The graph below shows the position of <font color=\"red\">you</font>, the <font color=\"yellow\">speakers</font> and a <font color=\"green\">moving sound source</font> as if seen from above. You should hear the audio move between the channels."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
 
-	QHBoxLayout *h = new QHBoxLayout();
-
-	QVBoxLayout *subv = new QVBoxLayout();
-
-	qcbHeadphone = new QCheckBox(tr("Use headphones"));
+	qcbHeadphone = new QCheckBox(tr("Use headphones"), qwpage);
 	qcbHeadphone->setToolTip(tr("Use headphones instead of speakers."));
 	qcbHeadphone->setWhatsThis(tr("This ignores the OS speaker configuration and configures the positioning for headphones instead."));
 	qcbHeadphone->setObjectName(QLatin1String("Headphone"));
 	qcbHeadphone->setChecked(g.s.bPositionalHeadphone);
-	subv->addWidget(qcbHeadphone);
+	v->addWidget(qcbHeadphone);
 
 
 	fAngle = 0.0f;
@@ -286,55 +271,45 @@ QWizardPage *AudioWizard::positionalPage() {
 	qgsScene = NULL;
 	qgiSource = NULL;
 	asSource = NULL;
-	qgvView = new QGraphicsView();
+	qgvView = new QGraphicsView(qwpage);
 	qgvView->scale(1.0f, -1.0f);
-	subv->addWidget(qgvView);
 	qgvView->viewport()->installEventFilter(this);
 
-	h->addLayout(subv);
-
-	subv = new QVBoxLayout();
-
-	h->addLayout(subv);
-
-	v->addLayout(h);
-
-	qwpage->setLayout(v);
-
+	v->addWidget(qgvView);
 
 	return qwpage;
 }
 
 QWizardPage *AudioWizard::volumePage() {
-	QWizardPage *qwpage = new QWizardPage;
+	QWizardPage *qwpage = new QWizardPage(this);
 	qwpage->setTitle(tr("Volume tuning"));
 	qwpage->setSubTitle(tr("Tuning microphone hardware volume to optimal settings."));
 
-	QVBoxLayout *v = new QVBoxLayout();
+	QVBoxLayout *v = new QVBoxLayout(qwpage);
 	QLabel *l;
 
 	l = new QLabel(tr("Open your sound control panel and go to the recording settings. "
-	                  "Make sure the microphone is selected as active input with maximum recording volume. If there's an option to enable a \"Microphone boost\" make sure it's checked."));
+	                  "Make sure the microphone is selected as active input with maximum recording volume. If there's an option to enable a \"Microphone boost\" make sure it's checked."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
 
 	l = new QLabel(tr("Speak loudly, as when you are annoyed or excited. "
 	                  "Decrease the volume in the sound control panel until the bar below stays as high as possible in the blue and green "
 	                  "but <b>not</b> the red "
-	                  "zone while you speak."));
+	                  "zone while you speak."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
 
-	abAmplify = new AudioBar();
+	abAmplify = new AudioBar(qwpage);
 	abAmplify->qcBelow = Qt::blue;
 	v->addWidget(abAmplify);
 
 	l = new QLabel(tr("Now talk softly, as you would when talking late at night and you don't want to disturb anyone. "
-	                  "Adjust the slider below so that the bar moves into green when you talk, but stays blue while you're silent."));
+	                  "Adjust the slider below so that the bar moves into green when you talk, but stays blue while you're silent."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
 
-	qsMaxAmp = new QSlider(Qt::Horizontal);
+	qsMaxAmp = new QSlider(Qt::Horizontal, qwpage);
 	qsMaxAmp->setRange(1, 32767);
 	qsMaxAmp->setSingleStep(100);
 	qsMaxAmp->setPageStep(1000);
@@ -343,28 +318,26 @@ QWizardPage *AudioWizard::volumePage() {
 
 	v->addWidget(qsMaxAmp);
 
-	qwpage->setLayout(v);
-
 	return qwpage;
 }
 
 QWizardPage *AudioWizard::triggerPage() {
-	QWizardPage *qwpage = new QWizardPage;
+	QWizardPage *qwpage = new QWizardPage(this);
 	qwpage->setTitle(tr("Voice Activity Detection"));
 	qwpage->setSubTitle(tr("Letting Mumble figure out when you're talking and when you're silent."));
 
-	QVBoxLayout *v = new QVBoxLayout();
+	QVBoxLayout *v = new QVBoxLayout(qwpage);
 	QLabel *l;
 
-	l = new QLabel(tr("This will help Mumble figure out when you are talking. The first step is selecting which data value to use."));
+	l = new QLabel(tr("This will help Mumble figure out when you are talking. The first step is selecting which data value to use."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
 
-	qrAmplitude = new QRadioButton(tr("Raw amplitude from input"));
+	qrAmplitude = new QRadioButton(tr("Raw amplitude from input"), qwpage);
 	qrAmplitude->setObjectName(QLatin1String("Amplitude"));
 	v->addWidget(qrAmplitude);
 
-	qrSNR = new QRadioButton(tr("Signal-To-Noise ratio"));
+	qrSNR = new QRadioButton(tr("Signal-To-Noise ratio"), qwpage);
 	qrSNR->setObjectName(QLatin1String("SNR"));
 	v->addWidget(qrSNR);
 
@@ -377,7 +350,7 @@ QWizardPage *AudioWizard::triggerPage() {
 			break;
 	}
 
-	abVAD = new AudioBar();
+	abVAD = new AudioBar(qwpage);
 	abVAD->qcBelow = Qt::red;
 	abVAD->qcInside = Qt::yellow;
 	abVAD->qcAbove = Qt::green;
@@ -386,11 +359,11 @@ QWizardPage *AudioWizard::triggerPage() {
 
 	l = new QLabel(tr("Next you need to adjust the following two sliders. The first few utterances you say should end up in the "
 	                  "green area (definitive speech). While talking, you should stay inside the yellow (might be speech) and when you're "
-	                  "not talking, everything should be in the red (definitively not speech)."));
+	                  "not talking, everything should be in the red (definitively not speech)."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
 
-	qsMinVAD = new QSlider(Qt::Horizontal);
+	qsMinVAD = new QSlider(Qt::Horizontal, qwpage);
 	qsMinVAD->setRange(1, 32767);
 	qsMinVAD->setSingleStep(100);
 	qsMinVAD->setPageStep(1000);
@@ -399,7 +372,7 @@ QWizardPage *AudioWizard::triggerPage() {
 
 	v->addWidget(qsMinVAD);
 
-	qsMaxVAD = new QSlider(Qt::Horizontal);
+	qsMaxVAD = new QSlider(Qt::Horizontal, qwpage);
 	qsMaxVAD->setRange(1, 32767);
 	qsMaxVAD->setSingleStep(100);
 	qsMaxVAD->setPageStep(1000);
@@ -409,20 +382,20 @@ QWizardPage *AudioWizard::triggerPage() {
 	v->addWidget(qsMaxVAD);
 
 	l = new QLabel(tr("Last, you need to adjust the grace time. Mumble may detect this much non-speech and still keep transmitting before "
-	                  "it breaks off. This allows you to catch your breath while speaking."));
+	                  "it breaks off. This allows you to catch your breath while speaking."), qwpage);
 	l->setWordWrap(true);
 	v->addWidget(l);
 
 	QHBoxLayout *h = new QHBoxLayout;
 
-	qsHoldtime = new QSlider(Qt::Horizontal);
+	qsHoldtime = new QSlider(Qt::Horizontal, qwpage);
 	qsHoldtime->setRange(20, 250);
 	qsHoldtime->setSingleStep(5);
 	qsHoldtime->setPageStep(25);
 	qsHoldtime->setValue(g.s.iVoiceHold);
 	qsHoldtime->setObjectName(QLatin1String("Holdtime"));
 
-	qlHoldtime = new QLabel();
+	qlHoldtime = new QLabel(qwpage);
 	qlHoldtime->setMinimumWidth(40);
 	on_Holdtime_valueChanged(qsHoldtime->value());
 
@@ -431,31 +404,29 @@ QWizardPage *AudioWizard::triggerPage() {
 
 	v->addLayout(h);
 
-	qwpage->setLayout(v);
-
 	return qwpage;
 }
 
 QWizardPage *AudioWizard::deviceTuningPage() {
-	QWizardPage *qwpage = new QWizardPage;
+	QWizardPage *qwpage = new QWizardPage(this);
 	qwpage->setTitle(tr("Device tuning"));
 	qwpage->setSubTitle(tr("Changing hardware output delays to their minimum value."));
 
-	QGridLayout *grid = new QGridLayout();
+	QGridLayout *grid = new QGridLayout(qwpage);
 
 	QLabel *l = new QLabel(tr("To keep latency to an absolute minium, it's important to buffer as little audio as possible on the soundcard. "
 	                          "However, many soundcards report that they require a much smaller buffer than what they can actually work with, "
-	                          "so the only way to set this value is to try and fail."));
+	                          "so the only way to set this value is to try and fail."), qwpage);
 	l->setWordWrap(true);
 	grid->addWidget(l, 0, 0, 1, 2);
 
 	l = new QLabel(tr("You should hear a single tone that's changing in frequency. Change the slider below to the lowest value which gives <b>no</b> interruptions or jitter "
 	                  "in the sound. Please note that local echo is disabled during this test to "
-	                  "improve audio path recognition."));
+	                  "improve audio path recognition."), qwpage);
 	l->setWordWrap(true);
 	grid->addWidget(l, 1, 0, 1, 2);
 
-	qsOutputDelay = new QSlider(Qt::Horizontal);
+	qsOutputDelay = new QSlider(Qt::Horizontal, qwpage);
 	qsOutputDelay->setRange(1, 6);
 
 	qsOutputDelay->setSingleStep(1);
@@ -463,7 +434,7 @@ QWizardPage *AudioWizard::deviceTuningPage() {
 	qsOutputDelay->setValue(g.s.iOutputDelay);
 	qsOutputDelay->setObjectName(QLatin1String("OutputDelay"));
 
-	qlOutputDelay=new QLabel();
+	qlOutputDelay=new QLabel(qwpage);
 	qlOutputDelay->setMinimumWidth(30);
 	on_OutputDelay_valueChanged(qsOutputDelay->value());
 	qsOutputDelay->setToolTip(tr("Amount of data to buffer."));
@@ -475,14 +446,13 @@ QWizardPage *AudioWizard::deviceTuningPage() {
 
 	l = new QLabel(tr("If you position the microphone so it can pick up the speakers or headset, Mumble will measure the total audio path "
 	                  "delay in your system; this means the delay from a sample is placed in an outbound buffer until it's found in "
-	                  "a matching incoming buffer."));
+	                  "a matching incoming buffer."), qwpage);
 	l->setWordWrap(true);
 	grid->addWidget(l, 3, 0, 1, 2);
 
-	qlAudioPath = new QLabel();
+	qlAudioPath = new QLabel(qwpage);
 	grid->addWidget(qlAudioPath, 4, 0, 1, 2);
 
-	qwpage->setLayout(grid);
 	return qwpage;
 }
 
@@ -613,10 +583,10 @@ void AudioWizard::showPage(int v) {
 }
 
 int AudioWizard::nextId() const {
-	int next = QWizard::nextId();
+	int nextid = QWizard::nextId();
 	if (currentPage() == qwpTrigger && ! g.s.bPositionalAudio)
-		next++;
-	return next;
+		nextid++;
+	return nextid;
 }
 
 void AudioWizard::playChord() {
@@ -694,7 +664,7 @@ void AudioWizard::on_Ticker_timeout() {
 	if (! ai || ! ao)
 		return;
 
-	int iPeak = static_cast<int>(32767.f * powf(10.0f, (ai->dPeakMic / 20.0f)));
+	int iPeak = static_cast<int>(ai->dMaxMic);
 
 	if (iTicks++ >= 50) {
 		iMaxPeak = 0;
@@ -712,11 +682,9 @@ void AudioWizard::on_Ticker_timeout() {
 	abVAD->iAbove = qsMaxVAD->value();
 
 	if (g.s.vsVAD == Settings::Amplitude) {
-		abVAD->iValue = iPeak;
-		abVAD->iPeak = iMaxPeak;
+		abVAD->iValue = lroundf((32767.f/96.0f) * (96.0f + ai->dPeakMic));
 	} else {
 		abVAD->iValue = static_cast<int>(ai->fSpeechProb * 32767.0);
-		abVAD->iPeak = -1;
 	}
 	abVAD->update();
 
@@ -740,16 +708,14 @@ void AudioWizard::on_Ticker_timeout() {
 			qgiSource = qgsScene->addEllipse(QRectF(-.15f, -.15f, 0.3f, 0.3f), QPen(Qt::black), QBrush(Qt::green));
 			qgvView->setScene(qgsScene);
 			qgvView->fitInView(-4.0f, -4.0f, 8.0f, 8.0f, Qt::KeepAspectRatio);
-
-			qWarning("It's at %f %f", qgiSource->x(), qgiSource->y());
 		}
 	} else if (currentPage() == qwpPositional) {
 		float xp, yp;
 		if ((fX == 0.0f) && (fY == 0.0f)) {
-			fAngle += 0.05;
+			fAngle += 0.05f;
 
-			xp = sin(fAngle) * 2.0f;
-			yp = cos(fAngle) * 2.0f;
+			xp = sinf(fAngle) * 2.0f;
+			yp = cosf(fAngle) * 2.0f;
 		} else {
 			xp = fX;
 			yp = fY;
@@ -763,17 +729,17 @@ void AudioWizard::on_Ticker_timeout() {
 }
 
 void AudioWizard::on_VADmin_valueChanged(int v) {
-	g.s.fVADmin = v / 32767.0f;
+	g.s.fVADmin = static_cast<float>(v) / 32767.0f;
 }
 
 void AudioWizard::on_VADmax_valueChanged(int v) {
-	g.s.fVADmax = v / 32767.0f;
+	g.s.fVADmax = static_cast<float>(v) / 32767.0f;
 }
 
 void AudioWizard::on_Holdtime_valueChanged(int v) {
 	g.s.iVoiceHold = v;
 
-	float val = v * 20;
+	float val = static_cast<float>(v) * 20.0f;
 	val = val / 1000.0f;
 	qlHoldtime->setText(tr("%1 s").arg(val, 0, 'f', 2));
 }
