@@ -30,6 +30,7 @@
 
 #include "ConnectDialog.h"
 #include "Global.h"
+#include "ServerHandler.h"
 
 TextSortedItem::TextSortedItem(QTreeWidget *p, const QStringList &strings) : QTreeWidgetItem(p, strings) {
 }
@@ -121,12 +122,12 @@ void ConnectDialog::accept() {
 		qsPassword = QString();
 		QStringList a = item->text(1).split(QLatin1Char(':'));
 		qsServer = a.at(0);
-		iPort = a.at(1).toInt();
+		usPort = a.at(1).toUShort();
 	} else {
 		qsServer = qleServer->text();
 		qsUsername = qleUsername->text();
 		qsPassword = qlePassword->text();
-		iPort = qlePort->text().toInt();
+		usPort = qlePort->text().toUShort();
 
 		int row = qlwServers->currentIndex().row();
 		g.s.iServerRow = (row >= 0) ? row : 0;
@@ -230,7 +231,7 @@ void ConnectDialog::on_Request_done(bool err) {
 				pi.name = e.attribute(QLatin1String("name"));
 				pi.url = e.attribute(QLatin1String("url"));
 				pi.ip = e.attribute(QLatin1String("ip"));
-				pi.port = e.attribute(QLatin1String("port")).toInt();
+				pi.port = e.attribute(QLatin1String("port")).toUShort();
 				qlPublicServers << pi;
 			}
 		}
@@ -266,7 +267,10 @@ void ConnectDialog::on_qpbAdd_clicked() {
 		if (! r.isEmpty()) {
 			const QModelIndex &previndex = qlwServers->currentIndex();
 			if (previndex.row() >= 0) {
-				qstmServers->setRecord(previndex.row(), r);
+				// FIXME: setRecord is bugged in 4.4.1
+				// qstmServers->setRecord(previndex.row(), r);
+				qstmServers->removeRows(previndex.row(), 1, QModelIndex());
+				qstmServers->insertRecord(-1, r);
 			} else {
 				qstmServers->insertRecord(-1, r);
 			}
@@ -305,11 +309,21 @@ void ConnectDialog::on_qpbAdd_clicked() {
 
 	qlwServers->setCurrentIndex(QModelIndex());
 
+	QString host, user, pw;
+	unsigned short port = 64738;
+
+	if (g.sh && g.sh->isRunning()) {
+		g.sh->getConnectionInfo(host, port, user, pw);
+	} else {
+		user = g.s.qsUsername;
+		pw = QString();
+		host = QLatin1String("host");
+	}
 	qleName->setText(tr("-Unnamed entry-"));
-	qleServer->setText(QString());
-	qleUsername->setText(g.s.qsUsername);
-	qlePassword->setText(QString());
-	qlePort->setText(QLatin1String("64738"));
+	qleServer->setText(host);
+	qleUsername->setText(user);
+	qlePassword->setText(pw);
+	qlePort->setText(QString::number(port));
 
 	qpbAdd->setText(tr("Add"));
 	qpbAdd->setEnabled(false);
