@@ -33,16 +33,7 @@
 
 #include "Settings.h"
 #include "Timer.h"
-
-#define MUMXTEXT(X) #X
-#define MUMTEXT(X) MUMXTEXT(X)
-
-#define MUMBLE_VERSION 1.1.4
-#if 0
-#define MUMBLE_RELEASE "Compiled " __DATE__ " " __TIME__
-#else
-#define MUMBLE_RELEASE MUMTEXT(MUMBLE_VERSION)
-#endif
+#include "Version.h"
 
 // Global helper class to spread variables around across threads.
 
