@@ -50,6 +50,7 @@ class GlobalShortcut : public QObject {
 		bool bActive;
 		int iNumUp;
 		QList<QVariant> qlButtons;
+		bool bSuppress;
 	signals:
 		void down();
 		void up();
@@ -77,6 +78,7 @@ class ShortcutKeyWidget : public QLineEdit {
 		virtual void focusInEvent(QFocusEvent *event);
 		virtual void focusOutEvent(QFocusEvent *event);
 		virtual void mouseDoubleClickEvent(QMouseEvent *e);
+		virtual bool eventFilter(QObject *, QEvent *);
 	public:
 		QList<QVariant> qlButtons;
 		bool bModified;
@@ -91,6 +93,7 @@ class GlobalShortcutConfig : public ConfigWidget {
 		Q_OBJECT
 	protected:
 		QHash<GlobalShortcut *, ShortcutKeyWidget *> qhKeys;
+		QHash<GlobalShortcut *, QCheckBox *> qhSuppress;
 	public:
 		GlobalShortcutConfig(Settings &st);
 		virtual QString title() const;
@@ -113,6 +116,8 @@ class GlobalShortcutEngine : public QThread {
 
 		QHash<int, GlobalShortcut *> qmShortcuts;
 		QList<QVariant> qlActiveButtons;
+		QList<QVariant> qlDownButtons;
+		QList<QVariant> qlSuppressed;
 
 		QList<QVariant> qlButtonList;
 		QList<QList<GlobalShortcut *> > qlShortcutList;
@@ -123,10 +128,11 @@ class GlobalShortcutEngine : public QThread {
 		virtual void needRemap();
 		void run();
 
-		void handleButton(const QVariant &, bool);
+		bool handleButton(const QVariant &, bool);
 		static void add(GlobalShortcut *);
 		static void remove(GlobalShortcut *);
 		virtual QString buttonName(const QVariant &) = 0;
+		virtual bool canSuppress();
 	signals:
 		void buttonPressed(bool last);
 };
