@@ -33,7 +33,9 @@
 #include <QX11Info>
 #include <X11/X.h>
 #include <X11/Xlib.h>
+#ifdef USE_XEVIE
 #include <X11/extensions/Xevie.h>
+#endif
 
 #ifdef Q_OS_LINUX
 #include <linux/input.h>
@@ -75,6 +77,7 @@ GlobalShortcutX::GlobalShortcutX() {
 	maj = 1;
 	min = 1;
 
+#ifdef USE_XEVIE
 	if (! XevieQueryVersion(display, &maj, &min)) {
 		qWarning("GlobalShortcutX: XEVIE extension not found. Enable it in xorg.conf");
 	} else {
@@ -89,7 +92,9 @@ GlobalShortcutX::GlobalShortcutX() {
 		}
 #endif
 	}
-
+#else
+	qWarning("GlobalShortcutX: Not compiled with XEVIE support.");
+#endif
 	if (! bXevie) {
 		qWarning("GlobalShortcutX: No XEVIE support, falling back to polled input. This wastes a lot of CPU resources, so please enable one of the other methods.");
 	}
@@ -103,12 +108,17 @@ GlobalShortcutX::~GlobalShortcutX() {
 	wait();
 }
 
+bool GlobalShortcutX::canSuppress() {
+	return bXevie;
+}
+
 void GlobalShortcutX::run() {
 	fd_set in_fds;
 	XEvent evt;
 	struct timeval tv;
 
 	if (bXevie) {
+#ifdef USE_XEVIE
 		while (bRunning) {
 			if (bNeedRemap)
 				remap();
@@ -118,8 +128,9 @@ void GlobalShortcutX::run() {
 			tv.tv_usec = 100000;
 			if (select(ConnectionNumber(display)+1, &in_fds, NULL, NULL, &tv)) {
 				while (XPending(display)) {
+					bool suppress = false;
 					XNextEvent(display, &evt);
-					XevieSendEvent(display, &evt, XEVIE_UNMODIFIED);
+
 					switch (evt.type) {
 						case KeyPress:
 						case KeyRelease:
@@ -132,16 +143,19 @@ void GlobalShortcutX::run() {
 								else
 									evtcode = 0x118 + evt.xbutton.button;
 
-								handleButton(evtcode, down);
+								suppress = handleButton(evtcode, down);
 							}
 							break;
 						default:
 							qWarning("GlobalShortcutX: EVT %x", evt.type);
 					}
+					if (! suppress)
+						XevieSendEvent(display, &evt, XEVIE_UNMODIFIED);
 				}
 			}
 		}
 		XevieEnd(display);
+#endif
 	} else {
 		Window root = XDefaultRootWindow(display);
 		Window root_ret, child_ret;
@@ -171,9 +185,9 @@ void GlobalShortcutX::run() {
 			} else {
 				for (int i=0;i<256;++i) {
 					int index = i / 8;
-					int mask = 1 << (i % 8);
-					bool oldstate = (keys[idx][index] & mask) != 0;
-					bool newstate = (keys[next][index] & mask) != 0;
+					int keymask = 1 << (i % 8);
+					bool oldstate = (keys[idx][index] & keymask) != 0;
+					bool newstate = (keys[next][index] & keymask) != 0;
 					if (oldstate != newstate) {
 						handleButton(i, newstate);
 					}
@@ -273,7 +287,7 @@ QString GlobalShortcutX::buttonName(const QVariant &v) {
 	if (!ok)
 		return QString();
 	if ((key < 0x118) || (key >= 0x128)) {
-		KeySym ks=XKeycodeToKeysym(QX11Info::display(), key, 0);
+		KeySym ks=XKeycodeToKeysym(QX11Info::display(), static_cast<KeyCode>(key), 0);
 		if (ks == NoSymbol) {
 			return QLatin1String("0x")+QString::number(key,16);
 		} else {
