@@ -112,12 +112,13 @@ MainWindow::MainWindow(QWidget *p) : QMainWindow(p) {
 	qiIcon.addFile(QLatin1String("skin:mumble.16x16.png"));
 	qiIcon.addFile(QLatin1String("skin:mumble.32x32.png"));
 	qiIcon.addFile(QLatin1String("skin:mumble.64x64.png"));
-
+#ifdef Q_OS_MAC
+	qiIcon.addFile(QLatin1String("skin:mumble.osx.png"));
+#else
 	// Set application icon except on MacOSX, where the window-icon
 	// shown in the title-bar usually serves as a draggable version of the
 	// current open document (i.e. you can copy the open document anywhere
 	// simply by dragging this icon).
-#ifndef Q_OS_MAC
 	qApp->setWindowIcon(qiIcon);
 #endif
 
@@ -143,6 +144,22 @@ MainWindow::MainWindow(QWidget *p) : QMainWindow(p) {
 	QList<QAction *> qla = findChildren<QAction *>();
 	foreach(QAction *a, qla)
 	a->setShortcutContext(Qt::ApplicationShortcut);
+
+	setOnTop(g.s.bAlwaysOnTop);
+}
+
+void MainWindow::setOnTop(bool top) {
+	Qt::WindowFlags wf = windowFlags();
+	if (wf.testFlag(Qt::WindowStaysOnTopHint) != top) {
+		if (top)
+			wf |= Qt::WindowStaysOnTopHint;
+		else
+			wf &= ~Qt::WindowStaysOnTopHint;
+		bNoHide = true;
+		setWindowFlags(wf);
+		show();
+		bNoHide = false;
+	}
 }
 
 void MainWindow::createActions() {
@@ -197,6 +214,12 @@ void MainWindow::createActions() {
 	gsMinimal=new GlobalShortcut(this, idx++, tr("Toggle Minimal", "Global Shortcut"));
 	gsMinimal->setObjectName(QLatin1String("ToggleMinimal"));
 
+	gsVolumeUp=new GlobalShortcut(this, idx++, tr("Volume Up (+10%)", "Global Shortcut"));
+	gsVolumeUp->setObjectName(QLatin1String("VolumeUp"));
+
+	gsVolumeDown=new GlobalShortcut(this, idx++, tr("Volume Down (-10%)", "Global Shortcut"));
+	gsVolumeDown->setObjectName(QLatin1String("VolumeDown"));
+
 	qstiIcon = new QSystemTrayIcon(qiIcon, this);
 	qstiIcon->setToolTip(tr("Mumble"));
 	qstiIcon->setObjectName(QLatin1String("Icon"));
@@ -267,7 +290,7 @@ void MainWindow::msgBox(QString msg) {
 
 void MainWindow::closeEvent(QCloseEvent *e) {
 #ifndef Q_OS_MAC
-	if (g.sh && g.sh->isRunning()) {
+	if (g.sh && g.sh->isRunning() && g.s.bAskOnQuit) {
 		QMessageBox mb(QMessageBox::Warning, tr("Mumble"), tr("Mumble is currently connected to a server. Do you want to Close or Minimize it?"), QMessageBox::NoButton, this);
 		QPushButton *qpbClose = mb.addButton(tr("Close"), QMessageBox::YesRole);
 		QPushButton *qpbMinimize = mb.addButton(tr("Minimize"), QMessageBox::NoRole);
@@ -327,6 +350,18 @@ void MainWindow::on_qtvPlayers_doubleClicked(const QModelIndex &idx) {
 	g.sh->sendMessage(&mpm);
 }
 
+void MainWindow::on_qteLog_customContextMenuRequested(const QPoint &mpos) {
+#if QT_VERSION >= 0x040400
+	QMenu *menu = qteLog->createStandardContextMenu(mpos);
+#else
+	QMenu *menu = qteLog->createStandardContextMenu();
+#endif
+	menu->addSeparator();
+	menu->addAction(tr("Clear"), qteLog, SLOT(clear(void)));
+	menu->exec(qteLog->mapToGlobal(mpos));
+	delete menu;
+}
+
 void MainWindow::openUrl(const QUrl &url) {
 	g.l->log(Log::Information, tr("Opening URL %1").arg(url.toString()));
 	if (url.scheme() != QLatin1String("mumble")) {
@@ -334,14 +369,14 @@ void MainWindow::openUrl(const QUrl &url) {
 		return;
 	}
 	QString host = url.host();
-	int port = url.port(64738);
+	unsigned short port = static_cast<unsigned short>(url.port(64738));
 	QString user = url.userName();
 	QString pw = url.password();
 	qsDesiredChannel = url.path();
 
 	if (g.sh && g.sh->isRunning()) {
 		QString oHost, oUser, oPw;
-		int oport;
+		unsigned short oport;
 		g.sh->getConnectionInfo(oHost, oport, oUser, oPw);
 
 		if ((user.isEmpty() || (user == oUser)) &&
@@ -436,7 +471,7 @@ void MainWindow::on_qaServerConnect_triggered() {
 	ConnectDialog *cd = new ConnectDialog(this);
 	int res = cd->exec();
 
-	if (cd->qsServer.isEmpty() || (cd->iPort==0) || cd->qsUsername.isEmpty())
+	if (cd->qsServer.isEmpty() || (cd->usPort==0) || cd->qsUsername.isEmpty())
 		res = QDialog::Rejected;
 
 	if (g.sh && g.sh->isRunning() && res == QDialog::Accepted) {
@@ -448,7 +483,7 @@ void MainWindow::on_qaServerConnect_triggered() {
 		qsDesiredChannel = QString();
 		rtLast = MessageServerReject::None;
 		qaServerDisconnect->setEnabled(true);
-		g.sh->setConnectionInfo(cd->qsServer, cd->iPort, cd->qsUsername, cd->qsPassword);
+		g.sh->setConnectionInfo(cd->qsServer, cd->usPort, cd->qsUsername, cd->qsPassword);
 		g.sh->start(QThread::TimeCriticalPriority);
 	}
 	delete cd;
@@ -604,7 +639,7 @@ void MainWindow::on_qaPlayerKick_triggered() {
 	if (!p)
 		return;
 
-	short session = p->uiSession;
+	unsigned int session = p->uiSession;
 
 	bool ok;
 	QString reason = QInputDialog::getText(this, tr("Kicking player %1").arg(p->qsName), tr("Enter reason"), QLineEdit::Normal, QString(), &ok);
@@ -626,7 +661,7 @@ void MainWindow::on_qaPlayerBan_triggered() {
 	if (!p)
 		return;
 
-	short session = p->uiSession;
+	unsigned int session = p->uiSession;
 
 	bool ok;
 	QString reason = QInputDialog::getText(this, tr("Banning player %1").arg(p->qsName), tr("Enter reason"), QLineEdit::Normal, QString(), &ok);
@@ -648,7 +683,7 @@ void MainWindow::on_qaPlayerTextMessage_triggered() {
 	if (!p)
 		return;
 
-	short session = p->uiSession;
+	unsigned int session = p->uiSession;
 
 	TextMessage tm;
 	tm.setWindowTitle(tr("Sending message to %1").arg(p->qsName));
@@ -670,7 +705,7 @@ void MainWindow::on_qaPlayerTextMessage_triggered() {
 }
 
 void MainWindow::on_qaQuit_triggered() {
-	qApp->closeAllWindows();
+	this->close();
 }
 
 void MainWindow::on_qmChannel_aboutToShow() {
@@ -956,8 +991,9 @@ void MainWindow::on_qaAudioUnlink_triggered() {
 }
 
 void MainWindow::on_qaConfigDialog_triggered() {
-	ConfigDialog dlg;
-	dlg.exec();
+	ConfigDialog *dlg= new ConfigDialog(this);
+	dlg->exec();
+	delete dlg;
 }
 
 void MainWindow::on_qaConfigMinimal_triggered() {
@@ -1028,6 +1064,22 @@ void MainWindow::on_CenterPos_triggered(bool down) {
 	}
 }
 
+void MainWindow::on_VolumeUp_triggered(bool down) {
+	if (down) {
+		float v = floorf(g.s.fVolume * 10.0f);
+		if (v < 10.0f)
+			g.s.fVolume = ++v / 10.0f;
+	}
+}
+
+void MainWindow::on_VolumeDown_triggered(bool down) {
+	if (down) {
+		float v = ceilf(g.s.fVolume * 10.0f);
+		if (v > 0.0f)
+			g.s.fVolume = --v / 10.0f;
+	}
+}
+
 void MainWindow::pushLink(bool down) {
 	if (down) {
 		g.iAltSpeak++;
@@ -1098,7 +1150,7 @@ void MainWindow::serverConnected() {
 	g.l->setIgnore(Log::PlayerJoin);
 	g.l->setIgnore(Log::OtherSelfMute);
 	QString host, uname, pw;
-	int port;
+	unsigned short port;
 	g.sh->getConnectionInfo(host, port, uname, pw);
 	g.l->log(Log::ServerConnected, tr("Connected to server %1.").arg(host));
 	qaServerDisconnect->setEnabled(true);
@@ -1123,7 +1175,7 @@ void MainWindow::serverDisconnected(QString reason) {
 	qaServerBanList->setEnabled(false);
 
 	QString uname, pw, host;
-	int port;
+	unsigned short port;
 	g.sh->getConnectionInfo(host, port, uname, pw);
 
 	if (aclEdit) {
@@ -1232,7 +1284,7 @@ void MainWindow::customEvent(QEvent *evt) {
 	}
 	if (evt->type() == MB_QEVENT) {
 		MessageBoxEvent *mbe=static_cast<MessageBoxEvent *>(evt);
-		g.l->log(Log::Warning, mbe->msg);
+		g.l->log(Log::Information, mbe->msg);
 		return;
 	}
 	if (evt->type() != SERVERSEND_EVENT)
