@@ -78,8 +78,7 @@ class MainWindow : public QMainWindow, public MessageHandler, public Ui::MainWin
 
 		GlobalShortcut *gsPushTalk, *gsResetAudio, *gsMuteSelf, *gsDeafSelf;
 		GlobalShortcut *gsUnlink, *gsCenterPos, *gsPushMute, *gsMetaChannel, *gsToggleOverlay;
-		GlobalShortcut *gsAltTalk;
-		GlobalShortcut *gsMinimal;
+		GlobalShortcut *gsAltTalk, *gsMinimal, *gsVolumeUp, *gsVolumeDown;
 		LogTitleBar *ltbDockTitle;
 
 		ACLEditor *aclEdit;
@@ -91,6 +90,8 @@ class MainWindow : public QMainWindow, public MessageHandler, public Ui::MainWin
 		void recheckTTS();
 
 		void msgBox(QString msg);
+
+		void setOnTop(bool top);
 	protected:
 		QTimer *qtReconnect;
 		void createActions();
@@ -140,12 +141,15 @@ class MainWindow : public QMainWindow, public MessageHandler, public Ui::MainWin
 		void on_qaHelpAboutQt_triggered();
 		void on_qaHelpVersionCheck_triggered();
 		void on_qaQuit_triggered();
+		void on_qteLog_customContextMenuRequested(const QPoint &pos);
 		void on_qteLog_anchorClicked(const QUrl &);
 		void on_qteLog_highlighted(const QUrl & link);
 		void on_PushToTalk_triggered(bool);
 		void on_PushToMute_triggered(bool);
 		void on_AltPushToTalk_triggered(bool);
 		void on_CenterPos_triggered(bool);
+		void on_VolumeUp_triggered(bool);
+		void on_VolumeDown_triggered(bool);
 		void on_Reconnect_timeout();
 		void on_Icon_activated(QSystemTrayIcon::ActivationReason);
 		void serverConnected();
