@@ -333,10 +333,9 @@ void MainWindow::msgServerSync(Connection *, MessageServerSync *msg) {
 
 void MainWindow::msgTextMessage(Connection *, MessageTextMessage *msg) {
 	MSG_INIT;
-	if (! pSrc)
-		return;
-	g.l->log(Log::TextMessage, MainWindow::tr("From %1: %2").arg(pSrc->qsName).arg(msg->qsMessage),
-	         MainWindow::tr("Message from %1").arg(pSrc->qsName));
+	const QString &name = pSrc ? pSrc->qsName : tr("Server", "message from");
+	g.l->log(Log::TextMessage, MainWindow::tr("From %1: %2").arg(name).arg(msg->qsMessage),
+	         MainWindow::tr("Message from %1").arg(name));
 }
 
 void MainWindow::msgEditACL(Connection *, MessageEditACL *msg) {
