@@ -95,7 +95,8 @@ class PlayerModel : public QAbstractItemModel {
 		QModelIndex index(Channel *) const;
 		QModelIndex index(ModelItem *) const;
 
-		void moveItem(ModelItem *oldparent, ModelItem *newparent, ModelItem *item);
+		void recursiveClone(const ModelItem *old, ModelItem *item, QModelIndexList &from, QModelIndexList &to);
+		ModelItem *moveItem(ModelItem *oldparent, ModelItem *newparent, ModelItem *item);
 
 		QString stringIndex(const QModelIndex &index) const;
 	public:
@@ -140,7 +141,7 @@ class PlayerModel : public QAbstractItemModel {
 		void expandAll(Channel *c);
 		void collapseEmpty(Channel *c);
 
-		QVariant otherRoles(int column, int role, bool isPlayer) const;
+		QVariant otherRoles(const QModelIndex &idx, int role) const;
 	public slots:
 		void playerTalkingChanged(bool talking);
 		void playerMuteDeafChanged();
