@@ -41,7 +41,6 @@ Settings::Settings() {
 	iTTSVolume = 75;
 	iTTSThreshold = 250;
 	iQuality = 6;
-	iComplexity = 4;
 	fVolume = 1.0f;
 	iMinLoudness = 1000;
 	iVoiceHold = 50;
@@ -66,7 +65,10 @@ Settings::Settings() {
 
 	bFirstTime = true;
 	ceExpand = ChannelsWithPlayers;
+	ceChannelDrag = Ask;
 	bMinimalView = false;
+	bAlwaysOnTop = false;
+	bAskOnQuit = true;
 
 	iOutputDelay = 5;
 
@@ -89,14 +91,18 @@ Settings::Settings() {
 	bOverlayUserTextures=true;
 	osOverlay = All;
 	bOverlayAlwaysSelf = true;
-	fOverlayX = 1.0f;
+	fOverlayX = 0.8f;
 	fOverlayY = 0.0f;
 	bOverlayTop = false;
 	bOverlayBottom = true;
 	bOverlayLeft = true;
 	bOverlayRight = false;
+#ifdef Q_OS_WIN
+	qfOverlayFont = QFont(QLatin1String("Comic Sans MS"), 20);
+#else
 	qfOverlayFont = QFont(QLatin1String("Arial"), 20);
-	fOverlayHeight = 30.0f;
+#endif
+	fOverlayHeight = .03f;
 	qcOverlayPlayer = QColor(255,255,255,128);
 	qcOverlayTalking = QColor(255,255,196,255);
 	qcOverlayAltTalking = QColor(255,128,128,255);
@@ -120,6 +126,9 @@ Settings::Settings() {
 	for (int i=Log::firstMsgType;i<=Log::lastMsgType;++i)
 		qmMessages.insert(i, Settings::LogConsole | Settings::LogTTS);
 
+	qmMessages[Log::DebugInfo] = Settings::LogConsole;
+	qmMessages[Log::Information] = Settings::LogConsole;
+
 	iServerRow = -1;
 }
 
@@ -150,6 +159,7 @@ BOOST_TYPEOF_REGISTER_TYPE(Settings::LoopMode)
 BOOST_TYPEOF_REGISTER_TYPE(Settings::OverlayShow)
 BOOST_TYPEOF_REGISTER_TYPE(Settings::ProxyType)
 BOOST_TYPEOF_REGISTER_TYPE(Settings::ChannelExpand)
+BOOST_TYPEOF_REGISTER_TYPE(Settings::ChannelDrag)
 BOOST_TYPEOF_REGISTER_TYPE(QString)
 BOOST_TYPEOF_REGISTER_TYPE(QByteArray)
 BOOST_TYPEOF_REGISTER_TYPE(QColor)
@@ -167,7 +177,6 @@ void Settings::load() {
 	SAVELOAD(uiDoublePush, "audio/doublepush");
 	SAVELOAD(bPushClick, "audio/pushclick");
 	SAVELOAD(iQuality, "audio/quality");
-	SAVELOAD(iComplexity, "audio/complexity");
 	SAVELOAD(iMinLoudness, "audio/loudness");
 	SAVELOAD(fVolume, "audio/volume");
 	LOADENUM(vsVAD, "audio/vadsource");
@@ -247,6 +256,9 @@ void Settings::load() {
 	SAVELOAD(qsStyle, "ui/style");
 	SAVELOAD(qsSkin, "ui/skin");
 	LOADENUM(ceExpand, "ui/expand");
+	LOADENUM(ceChannelDrag, "ui/drag");
+	SAVELOAD(bAlwaysOnTop, "ui/alwaysontop");
+	SAVELOAD(bAskOnQuit, "ui/askonquit");
 	SAVELOAD(bMinimalView, "ui/minimalview");
 	SAVELOAD(bPlayerTop, "ui/playertop");
 	SAVELOAD(bFirstTime, "ui/firsttime");
@@ -262,6 +274,7 @@ void Settings::load() {
 	for (int i=0;i<nshorts;i++) {
 		g.qs->setArrayIndex(i);
 		SAVELOAD(qmShortcuts[i], "keys");
+		SAVELOAD(qmShortcutSuppress[i], "suppress");
 	}
 	g.qs->endArray();
 
@@ -285,7 +298,6 @@ void Settings::save() {
 	SAVELOAD(uiDoublePush, "audio/doublepush");
 	SAVELOAD(bPushClick, "audio/pushclick");
 	SAVELOAD(iQuality, "audio/quality");
-	SAVELOAD(iComplexity, "audio/complexity");
 	SAVELOAD(iMinLoudness, "audio/loudness");
 	SAVELOAD(fVolume, "audio/volume");
 	SAVELOAD(vsVAD, "audio/vadsource");
@@ -365,6 +377,9 @@ void Settings::save() {
 	SAVELOAD(qsStyle, "ui/style");
 	SAVELOAD(qsSkin, "ui/skin");
 	SAVELOAD(ceExpand, "ui/expand");
+	SAVELOAD(ceChannelDrag, "ui/drag");
+	SAVELOAD(bAlwaysOnTop, "ui/alwaysontop");
+	SAVELOAD(bAskOnQuit, "ui/askonquit");
 	SAVELOAD(bMinimalView, "ui/minimalview");
 	SAVELOAD(bPlayerTop, "ui/playertop");
 	SAVELOAD(bFirstTime, "ui/firsttime");
@@ -381,6 +396,7 @@ void Settings::save() {
 	for (ShortcutMap::const_iterator it = qmShortcuts.constBegin(); it != qmShortcuts.constEnd(); ++it) {
 		g.qs->setArrayIndex(it.key());
 		SAVELOAD(qmShortcuts[it.key()], "keys");
+		SAVELOAD(qmShortcutSuppress[it.key()], "suppress");
 	}
 	g.qs->endArray();
 
