@@ -46,6 +46,7 @@ struct Settings {
 	enum LoopMode { None, Local, Server };
 	enum OverlayShow { Nothing, Talking, All };
 	enum ChannelExpand { NoChannels, ChannelsWithPlayers, AllChannels };
+	enum ChannelDrag { Ask, DoNothing, Move };
 	AudioTransmit atTransmit;
 	quint64 uiDoublePush;
 
@@ -57,7 +58,7 @@ struct Settings {
 	bool bTTS;
 	bool bPlayerTop;
 	int iTTSVolume, iTTSThreshold;
-	int iQuality, iComplexity, iMinLoudness, iVoiceHold, iJitterBufferSize;
+	int iQuality, iMinLoudness, iVoiceHold, iJitterBufferSize;
 	int iNoiseSuppress;
 	VADSource vsVAD;
 	float fVADmin, fVADmax;
@@ -100,6 +101,7 @@ struct Settings {
 
 	typedef QMap<int, QList<QVariant > > ShortcutMap;
 	ShortcutMap qmShortcuts;
+	QMap<int, bool> qmShortcutSuppress;
 
 	enum MessageLog { LogConsole = 0x01, LogTTS = 0x02};
 	QMap<int, quint32> qmMessages;
@@ -110,7 +112,10 @@ struct Settings {
 	bool bFirstTime;
 	QByteArray qbaMainWindowGeometry, qbaMainWindowState, qbaSplitterState, qbaHeaderState;
 	ChannelExpand ceExpand;
+	ChannelDrag ceChannelDrag;
 	bool bMinimalView;
+	bool bAlwaysOnTop;
+	bool bAskOnQuit;
 
 	QString qsUsername;
 	int iServerRow;
