@@ -38,7 +38,7 @@
 #include "Log.h"
 #include "Plugins.h"
 #include "Global.h"
-#ifndef Q_OS_MAC
+#ifdef USE_DBUS
 #include "DBus.h"
 #endif
 #include "VersionCheck.h"
@@ -53,12 +53,13 @@ void throw_exception(std::exception const &) {
 #endif
 
 extern void os_init();
+extern char *os_url;
+extern char *os_lang;
 
 int main(int argc, char **argv) {
-	// Check for SSE and MMX, but only in the windows binaries
-
 	int res;
-#ifdef Q_OS_WIN
+
+#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
 	os_init();
 #endif
 
@@ -90,7 +91,7 @@ int main(int argc, char **argv) {
 		if (reqSize > 0) {
 			STACKVAR(wchar_t, buff, reqSize+1);
 			_wgetenv_s(&reqSize, buff, reqSize, L"PATH");
-			QString path = QString::fromLatin1("%1\\bin;%1;%2").arg(QDir::toNativeSeparators(a.applicationDirPath())).arg(QString::fromWCharArray(buff));
+			QString path = QString::fromLatin1("%1;%2").arg(QDir::toNativeSeparators(a.applicationDirPath())).arg(QString::fromWCharArray(buff));
 			STACKVAR(wchar_t, buffout, path.length() + 1);
 			path.toWCharArray(buffout);
 			_wputenv_s(L"PATH", buffout);
@@ -135,20 +136,32 @@ int main(int argc, char **argv) {
 	}
 
 	QDir::addSearchPath(QLatin1String("skin"),QLatin1String(":/"));
-	QDir::addSearchPath(QLatin1String("translation"), a.applicationDirPath());
 	QDir::addSearchPath(QLatin1String("translation"), QLatin1String(":/"));
 
-	qWarning("Locale is %s", qPrintable(QLocale::system().name()));
+	QString qsSystemLocale = QLocale::system().name();
 
-	QString locale = g.s.qsLanguage.isEmpty() ? QLocale::system().name() : g.s.qsLanguage;
+#ifdef Q_OS_MAC
+	if (os_lang) {
+		qWarning("Using Mac OS X system langauge as locale name");
+		qsSystemLocale = QString(os_lang);
+	}
+#endif
+
+	qWarning("Locale is %s", qPrintable(qsSystemLocale));
+
+	QString locale = g.s.qsLanguage.isEmpty() ? qsSystemLocale : g.s.qsLanguage;
 
 	QTranslator translator;
-	translator.load(QLatin1String("translation:mumble_") + locale);
-	a.installTranslator(&translator);
+	if (translator.load(QLatin1String("translation:mumble_") + locale))
+		a.installTranslator(&translator);
+
+	QTranslator loctranslator;
+	if (loctranslator.load(QLatin1String("mumble_") + locale, a.applicationDirPath()))
+		a.installTranslator(&loctranslator);
 
 	QTranslator qttranslator;
-	qttranslator.load(QLatin1String("translation:qt_") + locale);
-	a.installTranslator(&qttranslator);
+	if (qttranslator.load(QLatin1String("translation:qt_") + locale))
+		a.installTranslator(&qttranslator);
 
 	// Initialize proxy settings
 	NetworkConfig::SetupProxy();
@@ -166,6 +179,13 @@ int main(int argc, char **argv) {
 	g.o = new Overlay();
 	g.o->setActive(g.s.bOverlayEnable);
 
+	// Process any waiting events before initializing our MainWindow.
+	// The mumble:// URL support for Mac OS X happens through AppleEvents,
+	// so we need to loop a little before we begin.  If we were launched
+	// through a URL, this should call a platform specific callback
+	// (in os_macx.cpp) and point the `os_url' global to a valid URL.
+	a.processEvents();
+
 	// Main Window
 	g.mw=new MainWindow(NULL);
 	g.mw->show();
@@ -206,9 +226,14 @@ int main(int argc, char **argv) {
 
 	if (a.arguments().count() > 1) {
 		g.mw->openUrl(QUrl(a.arguments().last()));
+#ifdef Q_OS_MAC
+	} else if (os_url) {
+		g.mw->openUrl(QUrl(QString(os_url)));
+#endif
 	} else {
 		g.mw->on_qaServerConnect_triggered();
 	}
+
 	res=a.exec();
 
 	g.s.save();
