@@ -502,6 +502,18 @@ void MurmurDBus::setPlayerState(const PlayerInfo &npi, const QDBusMessage &msg)
 		emit playerStateChanged(PlayerInfo(pPlayer));
 }
 
+void MurmurDBus::sendMessage(unsigned int session, const QString &text, const QDBusMessage &msg) {
+	PLAYER_SETUP;
+
+	server->sendTextMessage(NULL, pPlayer, false, text);
+}
+
+void MurmurDBus::sendMessageChannel(int id, bool tree, const QString &text, const QDBusMessage &msg) {
+	CHANNEL_SETUP_VAR(id);
+
+	server->sendTextMessage(cChannel, NULL, tree, text);
+}
+
 void MurmurDBus::addChannel(const QString &name, int chanparent, const QDBusMessage &msg, int &newid) {
 	CHANNEL_SETUP_VAR(chanparent);
 
@@ -526,6 +538,11 @@ void MurmurDBus::removeChannel(int id, const QDBusMessage &msg) {
 	server->removeChannel(cChannel, NULL);
 }
 
+void MurmurDBus::getChannelState(int id, const QDBusMessage &msg, ChannelInfo &state) {
+	CHANNEL_SETUP_VAR(id);
+	state = ChannelInfo(cChannel);
+}
+
 void MurmurDBus::setChannelState(const ChannelInfo &nci, const QDBusMessage &msg) {
 	CHANNEL_SETUP_VAR(nci.id);
 	ChannelInfo ci(cChannel);
@@ -533,6 +550,7 @@ void MurmurDBus::setChannelState(const ChannelInfo &nci, const QDBusMessage &msg
 	CHANNEL_SETUP_VAR2(cParent, nci.parent);
 
 	bool changed = false;
+	bool update = false;
 
 	QSet<Channel *> newset;
 	foreach(int id, nci.links) {
@@ -540,7 +558,18 @@ void MurmurDBus::setChannelState(const ChannelInfo &nci, const QDBusMessage &msg
 		newset << cLink;
 	}
 
-	if (cParent != cChannel->cParent) {
+	if (cChannel->qsName != nci.name) {
+		cChannel->qsName = nci.name;
+		MessageChannelRename mcr;
+		mcr.uiSession = 0;
+		mcr.iId = cChannel->iId;
+		mcr.qsName = nci.name;
+		server->sendAll(&mcr);
+		update = true;
+		changed = true;
+	}
+
+	if ((cParent != cChannel) && (cParent != cChannel->cParent)) {
 
 		Channel *p = cParent;
 		while (p) {
@@ -553,7 +582,6 @@ void MurmurDBus::setChannelState(const ChannelInfo &nci, const QDBusMessage &msg
 
 		cChannel->cParent->removeChannel(cChannel);
 		cParent->addChannel(cChannel);
-		server->updateChannel(cChannel);
 
 		MessageChannelMove mcm;
 		mcm.uiSession = 0;
@@ -561,6 +589,7 @@ void MurmurDBus::setChannelState(const ChannelInfo &nci, const QDBusMessage &msg
 		mcm.iParent = nci.parent;
 		server->sendAll(&mcm);
 
+		update = true;
 		changed = true;
 	}
 
@@ -599,6 +628,8 @@ void MurmurDBus::setChannelState(const ChannelInfo &nci, const QDBusMessage &msg
 		changed = true;
 	}
 
+	if (update)
+		server->updateChannel(cChannel);
 	if (changed)
 		emit channelStateChanged(ChannelInfo(cChannel));
 }
@@ -771,6 +802,15 @@ void MurmurDBus::getRegistration(int id, const QDBusMessage &msg, RegisteredPlay
 	player.email = email;
 }
 
+void MurmurDBus::setRegistration(int id, const QString &name, const QString &email, const QString &pw, const QDBusMessage &msg) {
+	RegisteredPlayer player;
+	player.id = id;
+	player.name = name;
+	player.email = email;
+	player.pw = pw;
+	updateRegistration(player, msg);
+}
+
 void MurmurDBus::updateRegistration(const RegisteredPlayer &player, const QDBusMessage &msg) {
 	QString name, email;
 	if (! server->getRegistration(player.id, name, email)) {
@@ -864,22 +904,9 @@ PlayerInfoExtended::PlayerInfoExtended(Player *p) : PlayerInfo(p) {
 	id = p->iId;
 	name = p->qsName;
 
-	User *u = static_cast<User *>(p);
-	BandwidthRecord *bw= & u->bwr;
-	onlinesecs = bw->qtFirst.elapsed() / 1000000LL;
-
-	bytespersec = 0;
-
-	int sincelast = bw->a_qtWhen[bw->iRecNum].elapsed() / 20000LL;
-	int todo = N_BANDWIDTH_SLOTS - sincelast;
-	if (todo < 0)
-		return;
-
-	int sum = 0;
-	for (int i=0;i<todo;i++) {
-		sum += bw->a_iBW[(bw->iRecNum + N_BANDWIDTH_SLOTS - i) % N_BANDWIDTH_SLOTS];
-	}
-	bytespersec= (sum * 50) / sincelast;
+	const User *u = static_cast<User *>(p);
+	onlinesecs = u->bwr.onlineSeconds();
+	bytespersec = u->bwr.bandwidth();
 }
 
 ChannelInfo::ChannelInfo(Channel *c) {
@@ -1033,12 +1060,12 @@ void MetaDBus::getAllConf(int server_id, const QDBusMessage &msg, ConfigMap &val
 	}
 }
 
-void MetaDBus::getLog(int server_id, int min_seconds, int max_seconds, const QDBusMessage &msg, QList<LogEntry> &entries) {
+void MetaDBus::getLog(int server_id, int min_offset, int max_offset, const QDBusMessage &msg, QList<LogEntry> &entries) {
 	if (! ServerDB::serverExists(server_id)) {
 		MurmurDBus::qdbc.send(msg.createErrorReply("net.sourceforge.mumble.Error.server", "Invalid server id"));
 	} else {
 		entries.clear();
-		QList<ServerDB::LogRecord> dblog = ServerDB::getLog(server_id, min_seconds, max_seconds);
+		QList<ServerDB::LogRecord> dblog = ServerDB::getLog(server_id, min_offset, max_offset);
 		foreach(const ServerDB::LogRecord &e, dblog) {
 			entries << LogEntry(e);
 		}
@@ -1081,3 +1108,7 @@ void MetaDBus::quit() {
 	qWarning("Quit requested from D-Bus");
 	QCoreApplication::instance()->quit();
 }
+
+void MetaDBus::getVersion(int &major, int &minor, int &patch, QString &text) {
+	Meta::getVersion(major, minor, patch, text);
+}
