@@ -70,16 +70,7 @@ void Server::msgServerAuthenticate(Connection *cCon, MessageServerAuthenticate *
 
 	MessageServerReject msr;
 	bool ok = false;
-
-	QRegExp re("[-=\\w\\[\\]\\{\\}\\(\\)\\@\\|\\.]+");
-
-	bool nameok = re.exactMatch(msg->qsUsername);
-	if (nameok && msg->qsUsername[0] == '@')
-		nameok = false;
-	if (nameok && msg->qsUsername[0] == '#')
-		nameok = false;
-	if (nameok && msg->qsUsername.length() > 512)
-		nameok = false;
+	bool nameok = Player::validateName(msg->qsUsername);
 
 	// Fetch ID and stored username.
 	// Since this may call DBus, which may recall our dbus messages, this function needs
@@ -430,7 +421,7 @@ void Server::msgPlayerMove(Connection *cCon, MessagePlayerMove *msg) {
 
 	sendAll(msg);
 	playerEnterChannel(pDstUser, c);
-	log(uSource, "Moved %s to %s",qPrintable(pDstUser->qsName), qPrintable(c->qsName));
+	log(uSource, "Moved %s to %s (%d)",qPrintable(pDstUser->qsName), qPrintable(c->qsName), c->iId);
 }
 
 void Server::msgChannelAdd(Connection *cCon, MessageChannelAdd *msg) {
@@ -445,9 +436,7 @@ void Server::msgChannelAdd(Connection *cCon, MessageChannelAdd *msg) {
 		return;
 	}
 
-	QRegExp re("[ \\-=\\w\\#\\[\\]\\{\\}\\(\\)\\@\\|]+");
-
-	if (! re.exactMatch(msg->qsName)) {
+	if (! Channel::validateName(msg->qsName)) {
 		PERM_DENIED_TEXT("Illegal channel name");
 		return;
 	}
@@ -501,9 +490,7 @@ void Server::msgChannelRename(Connection *cCon, MessageChannelRename *msg) {
 		return;
 	}
 
-	QRegExp re("[ -=\\w\\#\\[\\]\\{\\}\\(\\)\\@\\|]+");
-
-	if (! re.exactMatch(msg->qsName)) {
+	if (! Channel::validateName(msg->qsName)) {
 		PERM_DENIED_TEXT("Illegal channel name");
 		return;
 	}
