@@ -37,7 +37,7 @@ MetaParams Meta::mp;
 
 MetaParams::MetaParams() {
 	qsPassword = QString();
-	iPort = 64738;
+	usPort = 64738;
 	iTimeout = 30;
 	iMaxBandwidth = 10000;
 	iMaxUsers = 1000;
@@ -126,7 +126,7 @@ void MetaParams::read(QString fname) {
 	}
 
 	qsPassword = qs.value("serverpassword", qsPassword).toString();
-	iPort = qs.value("port", iPort).toInt();
+	usPort = static_cast<unsigned short>(qs.value("port", usPort).toUInt());
 	iTimeout = qs.value("timeout", iTimeout).toInt();
 	iMaxBandwidth = qs.value("bandwidth", iMaxBandwidth).toInt();
 	iDefaultChan = qs.value("defaultchannel", iDefaultChan).toInt();
@@ -140,8 +140,11 @@ void MetaParams::read(QString fname) {
 	qsDBPassword = qs.value("dbPassword", qsDBPassword).toString();
 	qsDBHostName = qs.value("dbHost", qsDBHostName).toString();
 	qsDBPrefix = qs.value("dbPrefix", qsDBPrefix).toString();
+	qsDBOpts = qs.value("dbOpts", qsDBOpts).toString();
 	iDBPort = qs.value("dbPort", iDBPort).toInt();
 
+	qsIceEndpoint = qs.value("ice", qsIceEndpoint).toString();
+
 	iLogDays = qs.value("logdays", iLogDays).toInt();
 
 	qsDBus = qs.value("dbus", qsDBus).toString();
@@ -161,6 +164,8 @@ void MetaParams::read(QString fname) {
 	QString qsSSLCert = qs.value("sslCert").toString();
 	QString qsSSLKey = qs.value("sslKey").toString();
 
+	qbaPassPhrase = qs.value("sslPassPhrase").toByteArray();
+
 	QByteArray crt, key;
 
 	if (! qsSSLCert.isEmpty()) {
@@ -200,14 +205,14 @@ void MetaParams::read(QString fname) {
 		QSsl::KeyAlgorithm alg = qscCert.publicKey().algorithm();
 
 		if (! key.isEmpty()) {
-			qskKey = QSslKey(key, alg);
+			qskKey = QSslKey(key, alg, QSsl::Pem, QSsl::PrivateKey, qbaPassPhrase);
 			if (qskKey.isNull()) {
 				qWarning("Failed to parse key file.");
 			}
 		}
 
 		if (! crt.isEmpty() && qskKey.isNull()) {
-			qskKey = QSslKey(crt, alg);
+			qskKey = QSslKey(crt, alg, QSsl::Pem, QSsl::PrivateKey, qbaPassPhrase);
 			if (! qskKey.isNull()) {
 				qWarning("Using key from certificate file.");
 			}
@@ -225,7 +230,7 @@ void MetaParams::read(QString fname) {
 	qmConfig.clear();
 	qmConfig.insert(QLatin1String("host"),qhaBind.toString());
 	qmConfig.insert(QLatin1String("password"),qsPassword);
-	qmConfig.insert(QLatin1String("port"),QString::number(iPort));
+	qmConfig.insert(QLatin1String("port"),QString::number(usPort));
 	qmConfig.insert(QLatin1String("timeout"),QString::number(iTimeout));
 	qmConfig.insert(QLatin1String("bandwidth"),QString::number(iMaxBandwidth));
 	qmConfig.insert(QLatin1String("users"),QString::number(iMaxUsers));
