@@ -39,7 +39,7 @@ struct MetaParams {
 	QDir qdBasePath;
 
 	QHostAddress qhaBind;
-	int iPort;
+	unsigned short usPort;
 	int iTimeout;
 	int iMaxBandwidth;
 	int iMaxUsers;
@@ -57,6 +57,7 @@ struct MetaParams {
 	QString qsDBPassword;
 	QString qsDBHostName;
 	QString qsDBPrefix;
+	QString qsDBOpts;
 	int iDBPort;
 
 	int iLogDays;
@@ -65,6 +66,7 @@ struct MetaParams {
 	QString qsDBusService;
 	QString qsLogfile;
 	QString qsPid;
+	QString qsIceEndpoint;
 
 	QString qsRegName;
 	QString qsRegPassword;
@@ -73,6 +75,7 @@ struct MetaParams {
 
 	QSslCertificate qscCert;
 	QSslKey qskKey;
+	QByteArray qbaPassPhrase;
 
 	QMap<QString, QString> qmConfig;
 
@@ -94,6 +97,7 @@ class Meta : public QObject {
 		bool banCheck(const QHostAddress &);
 		void kill(int);
 		void killAll();
+		static void getVersion(int &major, int &minor, int &patch, QString &string);
 };
 
 extern Meta *meta;
