@@ -92,7 +92,7 @@ void Server::update() {
 	tag=doc.createElement(QLatin1String("port"));
 	root.appendChild(tag);
 
-	t=doc.createTextNode(QString::number(iPort));
+	t=doc.createTextNode(QString::number(usPort));
 	tag.appendChild(t);
 
 	tag=doc.createElement(QLatin1String("url"));
@@ -128,7 +128,7 @@ void Server::done(bool err) {
 	if (! http || ! qssReg)
 		return;
 	if (err) {
-		log("Regstration failed: %s", qPrintable(http->errorString()));
+		log("Registration failed: %s", qPrintable(http->errorString()));
 	} else {
 		QByteArray qba = http->readAll();
 		log("Registration: %s", qPrintable(QString(QLatin1String(qba))));
