@@ -74,6 +74,7 @@ User::User(Server *p, QSslSocket *socket) : Connection(p, socket), Player() {
 	saiUdpAddress.sin_family = AF_INET;
 }
 
+
 Server::Server(int snum, QObject *p) : QThread(p) {
 	iServerNum = snum;
 
@@ -84,10 +85,10 @@ Server::Server(int snum, QObject *p) : QThread(p) {
 
 	connect(qtsServer, SIGNAL(newConnection()), this, SLOT(newClient()), Qt::QueuedConnection);
 
-	if (! qtsServer->listen(qhaBind, iPort))
-		log("Server: TCP Listen on port %d failed",iPort);
+	if (! qtsServer->listen(qhaBind, usPort))
+		log("Server: TCP Listen on port %d failed",usPort);
 
-	log("Server listening on port %d",iPort);
+	log("Server listening on port %d",usPort);
 
 #ifdef Q_OS_UNIX
 	sUdpSocket = ::socket(PF_INET, SOCK_DGRAM, 0);
@@ -110,10 +111,10 @@ Server::Server(int snum, QObject *p) : QThread(p) {
 		struct sockaddr_in addr;
 		memset(&addr, 0, sizeof(addr));
 		addr.sin_family = AF_INET;
-		addr.sin_port = htons(iPort);
+		addr.sin_port = htons(usPort);
 		addr.sin_addr.s_addr = htonl(qhaBind.toIPv4Address());
 		if (::bind(sUdpSocket, reinterpret_cast<sockaddr *>(&addr), sizeof(addr)) == SOCKET_ERROR) {
-			log("Failed to bind UDP Socket to port %d", iPort);
+			log("Failed to bind UDP Socket to port %d", usPort);
 		} else {
 #ifdef Q_OS_UNIX
 			int val = IPTOS_PREC_FLASHOVERRIDE | IPTOS_LOWDELAY | IPTOS_THROUGHPUT;
@@ -142,10 +143,13 @@ Server::Server(int snum, QObject *p) : QThread(p) {
 	dbus = new MurmurDBus(this);
 	if (MurmurDBus::qdbc.isConnected())
 		MurmurDBus::qdbc.registerObject(QString::fromLatin1("/%1").arg(iServerNum), this);
+
+	bRunning = true;
 }
 
 Server::~Server() {
 	qrwlUsers.lockForWrite();
+	bRunning = false;
 	terminate();
 	wait();
 	qrwlUsers.unlock();
@@ -159,7 +163,7 @@ Server::~Server() {
 
 void Server::readParams() {
 	qsPassword = Meta::mp.qsPassword;
-	iPort = Meta::mp.iPort + iServerNum - 1;
+	usPort = static_cast<unsigned short>(Meta::mp.usPort + iServerNum - 1);
 	iTimeout = Meta::mp.iTimeout;
 	iMaxBandwidth = Meta::mp.iMaxBandwidth;
 	iMaxUsers = Meta::mp.iMaxUsers;
@@ -191,7 +195,7 @@ void Server::readParams() {
 	}
 
 	qsPassword = getConf("password", qsPassword).toString();
-	iPort = getConf("port", iPort).toInt();
+	usPort = static_cast<unsigned short>(getConf("port", usPort).toUInt());
 	iTimeout = getConf("timeout", iTimeout).toInt();
 	iMaxBandwidth = getConf("bandwidth", iMaxBandwidth).toInt();
 	iMaxUsers = getConf("users", iMaxUsers).toInt();
@@ -239,7 +243,7 @@ BandwidthRecord::BandwidthRecord() {
 
 void BandwidthRecord::addFrame(int size) {
 	iSum -= a_iBW[iRecNum];
-	a_iBW[iRecNum] = size;
+	a_iBW[iRecNum] = static_cast<unsigned char>(size);
 	iSum += a_iBW[iRecNum];
 
 	a_qtWhen[iRecNum].restart();
@@ -249,15 +253,31 @@ void BandwidthRecord::addFrame(int size) {
 		iRecNum = 0;
 }
 
-int BandwidthRecord::bytesPerSec() {
+int BandwidthRecord::bytesPerSec() const {
 	quint64 elapsed = a_qtWhen[iRecNum].elapsed();
-	return (iSum * 1000000LL) / elapsed;
+	return static_cast<int>((iSum * 1000000LL) / elapsed);
+}
+
+int BandwidthRecord::onlineSeconds() const {
+	return static_cast<int>(qtFirst.elapsed() / 1000000LL);
+}
+
+int BandwidthRecord::bandwidth() const {
+	int sincelast = static_cast<int>(a_qtWhen[iRecNum].elapsed() / 20000LL);
+	int todo = N_BANDWIDTH_SLOTS - sincelast;
+	if (todo < 0)
+		return 0;
+
+	int sum = 0;
+	for (int i=0;i<todo;i++)
+		sum += a_iBW[(iRecNum+N_BANDWIDTH_SLOTS - i) % N_BANDWIDTH_SLOTS];
+	return (sum*50)/sincelast;
 }
 
 void Server::run() {
 	qint32 len;
-	char encrypted[65535];
-	char buffer[65535];
+	char encrypted[65536];
+	char buffer[65536];
 
 	quint32 msgType = 0;
 	unsigned int uiSession = 0;
@@ -269,7 +289,28 @@ void Server::run() {
 	int fromlen;
 #endif
 
-	forever {
+	while (bRunning) {
+#ifdef Q_OS_DARWIN
+		/*
+		 * Pthreads on Darwin suck.  They won't allow us to shut down the
+		 * server thread while we're in the recvfrom() syscall.
+		 *
+		 * We use this little hack to loop through our outer loop once in
+		 * a while to determine if we should still be running.
+		 */
+		static struct pollfd fds = {
+			sUdpSocket, POLLIN, 0
+		};
+		int ret = poll(&fds, 1, 1000);
+
+		if (ret == 0) {
+			continue;
+		} else if (ret == -1) {
+			qWarning("poll() failed: %s", strerror(errno));
+			break;
+		}
+#endif
+
 		fromlen = sizeof(from);
 		len=::recvfrom(sUdpSocket, encrypted, 65535, 0, reinterpret_cast<struct sockaddr *>(&from), &fromlen);
 
@@ -500,6 +541,7 @@ void Server::newClient() {
 
 		if (qqIds.isEmpty()) {
 			sock->disconnectFromHost();
+			sock->deleteLater();
 			return;
 		}
 
@@ -585,12 +627,6 @@ void Server::message(QByteArray &qbaMsg, Connection *cCon) {
 	}
 	Message *mMsg = Message::networkToMessage(qbaMsg);
 
-	// Just leftovers from the buffer and we just kicked
-	// the user off.
-	// FIXME :: We don't have anything like this now.
-	//if (cCon->isDeleted())
-	//	return;
-
 	if (mMsg) {
 		dispatch(cCon, mMsg);
 		delete mMsg;
@@ -612,7 +648,7 @@ void Server::checkTimeout() {
 	}
 	qrwlUsers.unlock();
 	foreach(User *u, qlClose)
-	u->disconnectSocket();
+	u->disconnectSocket(true);
 }
 
 void Server::tcpTransmitData(QByteArray a, unsigned int id) {
