@@ -58,7 +58,9 @@ struct BandwidthRecord {
 
 	BandwidthRecord();
 	void addFrame(int size);
-	int bytesPerSec();
+	int bytesPerSec() const;
+	int onlineSeconds() const;
+	int bandwidth() const;
 };
 
 class LogEmitter : public QObject {
@@ -92,14 +94,23 @@ class User : public Connection, public Player {
 		User(Server *parent, QSslSocket *socket);
 };
 
+class DBus;
+namespace Murmur {
+class ServerI;
+};
 
 class Server : public QThread, public MessageHandler {
+		friend class DBus;
+		friend class Murmur::ServerI;
 		Q_OBJECT;
 
+	protected:
+		bool bRunning;
+
 		// Former ServerParams
 	public:
 		QHostAddress qhaBind;
-		int iPort;
+		unsigned short usPort;
 		int iTimeout;
 		int iMaxBandwidth;
 		int iMaxUsers;
@@ -114,6 +125,7 @@ class Server : public QThread, public MessageHandler {
 
 		QSslCertificate qscCert;
 		QSslKey qskKey;
+		QByteArray qbaPassPhrase;
 
 		void readParams();
 
@@ -202,6 +214,19 @@ class Server : public QThread, public MessageHandler {
 		Server(int snum, QObject *parent = NULL);
 		~Server();
 
+		// RPC functions. Implementation in RPC.cpp
+	signals:
+		void playerStateChanged(const Player *);
+		void playerConnected(const Player *);
+		void playerDisconnected(const Player *);
+		void channelStateChanged(const Channel *);
+		void channelCreated(const Channel *);
+		void channelRemoved(const Channel *);
+	public:
+		void setPlayerState(Player *p, Channel *parent, bool mute, bool deaf, bool suppressed);
+		bool setChannelState(Channel *c, Channel *parent, const QString &qsName, const QSet<Channel *> &links);
+		void sendTextMessage(Channel *cChannel, User *pPlayer, bool tree, const QString &text);
+
 		// Database / DBus functions. Implementation in ServerDB.cpp
 		void initialize();
 		typedef QPair<quint32, int> qpBan;
