@@ -113,6 +113,7 @@ ServerDB::ServerDB() {
 		db->setPort(Meta::mp.iDBPort);
 		db->setUserName(Meta::mp.qsDBUserName);
 		db->setPassword(Meta::mp.qsDBPassword);
+		db->setConnectOptions(Meta::mp.qsDBOpts);
 		found = db->open();
 	}
 
@@ -449,6 +450,9 @@ int Server::registerPlayer(const QString &name) {
 	if (name.isEmpty())
 		return -1;
 
+	if (! Player::validateName(name))
+		return -1;
+
 	if (getUserID(name) >= 0)
 		return -1;
 
@@ -993,6 +997,8 @@ void Server::readChannels(Channel *p) {
 
 		while (query.next()) {
 			c = new Channel(query.value(0).toInt(), query.value(1).toString(), p);
+			if (! p)
+				c->setParent(this);
 			qhChannels.insert(c->iId, c);
 			c->bInheritACL = query.value(2).toBool();
 			kids << c;
@@ -1183,18 +1189,14 @@ void Server::dblog(const char *str) {
 	SQLEXEC();
 }
 
-QList<QPair<unsigned int, QString> > ServerDB::getLog(int server_id, unsigned int sec_min, unsigned int sec_max) {
+QList<QPair<unsigned int, QString> > ServerDB::getLog(int server_id, unsigned int offs_min, unsigned int offs_max) {
 	TransactionHolder th;
 	QSqlQuery &query = *th.qsqQuery;
 
-	QString qstr;
-	if (Meta::mp.qsDBDriver == "QSQLITE") {
-		qstr = QString::fromLatin1("msgtime > datetime('now','-%1 seconds') AND msgtime < datetime('now','-%2 seconds')").arg(sec_max).arg(sec_min);
-	} else {
-		qstr = QString::fromLatin1("msgtime > now() - INTERVAL %1 second AND msgtime < now() - INTERVAL %2 second").arg(sec_max).arg(sec_min);
-	}
-	ServerDB::prepare(query, QString::fromLatin1("SELECT msgtime, msg FROM %1slog WHERE server_id = ? AND ") + qstr);
+	SQLPREP("SELECT msgtime, msg FROM %1slog WHERE server_id = ? ORDER BY msgtime DESC LIMIT ?, ?");
 	query.addBindValue(server_id);
+	query.addBindValue(offs_min);
+	query.addBindValue(offs_max);
 	SQLEXEC();
 
 	QList<QPair<unsigned int, QString> > ql;
