@@ -53,8 +53,8 @@ class ServerDB {
 		static bool serverExists(int num);
 		static QMap<QString, QString> getAllConf(int server_id);
 		static QVariant getConf(int server_id, const QString &key, QVariant def = QVariant());
-		static void setConf(int server_id, const QString &key, const QVariant &value);
-		static QList<LogRecord> getLog(int server_id, unsigned int sec_min, unsigned int sec_max);
+		static void setConf(int server_id, const QString &key, const QVariant &value = QVariant());
+		static QList<LogRecord> getLog(int server_id, unsigned int offs_min, unsigned int offs_max);
 		static bool prepare(QSqlQuery &, const QString &, bool fatal = true);
 		static bool exec(QSqlQuery &, const QString &str = QString(), bool fatal= true);
 };
